trident package
===============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   trident.backend
   trident.callbacks
   trident.data
   trident.layers
   trident.loggers
   trident.misc
   trident.models
   trident.optims

Module contents
---------------

.. automodule:: trident
   :members:
   :undoc-members:
   :show-inheritance:
